searchData={"items":[{"type":"module","title":"opentelemetry_xray_id_generator","doc":"Generate trace_id and span_id compatible with AWS X-Ray. The X-Ray trace_id is a 64-bit identifier which is unique within a single trace. The first 32 bits is the timestamp, the remaining 96 bits are random. OpenTelemetry trace_ids are integers, so we combine the time and the unique id into a single 128-bit value. It is represented in text as three values separated by hyphens. For example, the trace_id {1-5759e988-bd862e3fe1be46a994272793} includes three values: version number 1, the time of the original request in Unix epoch time in hex, and finally a 96-bit identifier for the trace which is globally unique. https://docs.aws.amazon.com/xray/latest/devguide/xray-api-sendingdata.html#xray-api-traceids https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html https://aws-otel.github.io/docs/getting-started/x-ray#configuring-the-aws-x-ray-exporter","ref":"opentelemetry_xray_id_generator.html"},{"type":"function","title":"opentelemetry_xray_id_generator.generate_span_id/0","doc":"Generate 64-bit random integer to use as a span id.","ref":"opentelemetry_xray_id_generator.html#generate_span_id/0"},{"type":"function","title":"opentelemetry_xray_id_generator.generate_trace_id/0","doc":"Generate 128-bit random integer to use as trace id.","ref":"opentelemetry_xray_id_generator.html#generate_trace_id/0"},{"type":"module","title":"opentelemetry_xray_logger_filter","doc":"Erlang logger filter to format trace id in X-Ray format. This module implements a logger filter which converts the otel_trace_id field into a new xray_trace_id field in X-Ray format so log messages can be correlated with traces. See: * https://www.erlang.org/doc/man/logger#type-filter * https://github.com/aws/aws-xray-sdk-python/issues/188#issuecomment-982022464 * https://github.com/aws-observability/aws-otel-python/issues/46","ref":"opentelemetry_xray_logger_filter.html"},{"type":"function","title":"opentelemetry_xray_logger_filter.trace_id/2","doc":null,"ref":"opentelemetry_xray_logger_filter.html#trace_id/2"},{"type":"module","title":"opentelemetry_xray_propagator","doc":"Propagator that injects and extracts context from the AWS X-Ray tracing header. When the current app is downstream from another app or the AWS load balancer, the upstream app creates the trace for the current request and sends it in the &quot;X-Amzn-Trace-Id&quot; HTTP header. The header includes the trace id and optional information about the parent span and sampling. Similarly, when the current app makes calls to downstream services, it sets the header to pass the current trace context. NOTE: Amazon assumes that spans are not sampled by default. If you want your traces to be sampled, make sure that you turn it on. https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader","ref":"opentelemetry_xray_propagator.html"},{"type":"function","title":"opentelemetry_xray_propagator.encode_span_id/1","doc":"Encode span_id to string.","ref":"opentelemetry_xray_propagator.html#encode_span_id/1"},{"type":"function","title":"opentelemetry_xray_propagator.encode_trace_id/1","doc":"Encode trace_id to string.","ref":"opentelemetry_xray_propagator.html#encode_trace_id/1"},{"type":"function","title":"opentelemetry_xray_propagator.extract/5","doc":"Extract context from carrier.","ref":"opentelemetry_xray_propagator.html#extract/5"},{"type":"function","title":"opentelemetry_xray_propagator.fields/1","doc":"Return list of the keys the propagator sets with inject .","ref":"opentelemetry_xray_propagator.html#fields/1"},{"type":"function","title":"opentelemetry_xray_propagator.inject/4","doc":"Inject context into carrier.","ref":"opentelemetry_xray_propagator.html#inject/4"},{"type":"extras","title":"Overview","doc":"![test workflow](https://github.com/cogini/opentelemetry_xray/actions/workflows/test.yml/badge.svg)\n[![Module Version](https://img.shields.io/hexpm/v/opentelemetry_xray.svg)](https://hex.pm/packages/opentelemetry_xray)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/opentelemetry_xray)\n[![Total Download](https://img.shields.io/hexpm/dt/opentelemetry_xray.svg)](https://hex.pm/packages/opentelemetry_xray)\n[![License](https://img.shields.io/hexpm/l/opentelemetry_xray.svg)](https://github.com/cogini/opentelemetry_xray/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/cogini/opentelemetry_xray/main)](https://github.com/cogini/opentelemetry_xray/commits/main)\n[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)\n\n# opentelemetry_xray\n\n[OpenTelemetry](https://opentelemetry.io/) [AWS X-Ray](https://aws.amazon.com/xray/) support for Erlang/Elixir.\n\nIt works with the [AWS Distro for OpenTelemetry Collector](https://aws-otel.github.io/docs/getting-started/collector),\na version of the [OpenTelemetry Collector](https://opentelemetry.io/docs/collector/)\nwhich has support for AWS services such as X-Ray. This collector accepts standard\nOpenTelemetry traces, converts them to X-Ray format, and sends them to AWS. You\ncan run the collector as a sidecar container in an ECS task or as a daemon\non an EC2 instance.\n\nIn AWS X-Ray, the `trace_id` is a 128-bit value. The first 32 bits are a Unix\n`time_t` and the rest are a 96-bit random number. If you use the default\n`trace_id`, then X-Ray will reject your traces. This library generates ids that\nare compatible with X-Ray.\n\nWhen your app app is downstream from another app or the AWS load balancer, the\nupstream app creates the trace for the current request and sends it in the\n`X-Amzn-Trace-Id` HTTP header. The header includes the trace id and optional\ninformation about the parent span and sampling.\n\nThis library includes a propagator which reads the trace id from this header\nand uses it within your app. It can then pass the same trace id to downstream\napps via the header.\n\nNOTE: By default Amazon samples relatively few traces. If you want to ensure\nthat your traces are sampled, make sure that you turn on sampling in your app.\nA common approach is to turn on sampling for all traces that have errors\nand for some percentage of normal traces.\n\nThis library includes the following modules:\n\n* An id generator that creates X-Ray-compatible `trace_id` and `span_id`.\n  It implements the `otel_id_generator` protocol in the Erlang SDK.\n\n* A propagator that reads and writes AWS X-Ray trace context headers.\n  It implements the `otel_propagator_text_map` protocol in the Erlang SDK.\n\nLinks:\n\n* Propagators in general: https://opentelemetry.io/docs/specs/otel/context/api-propagators/\n* Erlang SDK propagation: https://opentelemetry.io/docs/instrumentation/erlang/propagation/\n* Erlang SDK id generator: https://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry/src/otel_id_generator.erl\n* X-Ray tracing header: https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader\n* X-Ray sampling: https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-sampling\n* X-Ray configuration: https://aws-otel.github.io/docs/getting-started/x-ray#configuring-the-aws-x-ray-exporter\n* AWS CloudWatch Log Group resource: https://github.com/aws/aws-xray-sdk-python/issues/188\n* OpenTelemetry resources: https://opentelemetry.io/docs/instrumentation/erlang/resources/\n* OpenTelemetry getting started: https://opentelemetry.io/docs/instrumentation/erlang/getting-started/\n* OpenTelemetry intro: https://davelucia.com/blog/observing-elixir-with-lightstep\n* Addding Erlang logger filters to new Elixir logger: https://write.as/yuriploc/elixir-logger-and-erlang-filters","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Erlang:\n\nAdd `opentelemetry_xray` to the list of dependencies in `rebar.config`:\n\n```erlang\n{deps, [opentelemetry_xray]}.\n```\n\nElixir:\n\nAdd `opentelemetry_xray` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:opentelemetry_xray, \"~> 0.7\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"Erlang:\n\nIn `sys.config`:\n\n```erlang\n{opentelemetry, {\n    id_generator, [opentelemetry_xray_id_generator],\n    propagators: [opentelemetry_xray_propagator, baggage]\n}}\n```\n\nElixir:\n\nIn `config/prod.exs`, configure `opentelemetry` to use this library:\n\n```elixir\nconfig :opentelemetry,\n  id_generator: :opentelemetry_xray_id_generator,\n  propagators: [:opentelemetry_xray_propagator, :baggage]\n```\n\nAdd resource attributes to the span to connect it to log messages:\n\n```shell\nexport OTEL_RESOURCE_ATTRIBUTES=\"aws.log.group.names=$AWS_LOG_GROUP\"\n```\n\nSee [phoenix_container_example](https://github.com/cogini/phoenix_container_example)\nfor a complete Elixir Phoenix app that uses this library.","ref":"readme.html#configuration"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.7.4] - 2025-04-22","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- Updated opentelemetry_api to 1.4\n\n## [0.7.3] - 2024-05-20","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Updated docs\n\n## [0.7.2] - 2024-05-20","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Upgrade opentelemetry_api\n\n## [0.7.1] - 2023-12-23","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Add logger filter to format trace_id\n- Update docs\n\n## [0.7.0] - 2023-10-30","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Update docs\n\n## [0.1.1] - 2023-10-23","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Update docs\n\n## [0.1.0] - 2023-10-23","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Create initial version","ref":"changelog.html#added"},{"type":"extras","title":"License (Apache 2.0)","doc":"# Apache License\nVersion 2.0, January 2004\n\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html"},{"type":"extras","title":"1. Definitions. - License (Apache 2.0)","doc":"\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.","ref":"license.html#1-definitions"},{"type":"extras","title":"2. Grant of Copyright License. - License (Apache 2.0)","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license"},{"type":"extras","title":"3. Grant of Patent License. - License (Apache 2.0)","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including a\ncross-claim or counterclaim in a lawsuit) alleging that the Work or a\nContribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license"},{"type":"extras","title":"4. Redistribution. - License (Apache 2.0)","doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n1. You must give any other recipients of the Work or Derivative Works a copy of\n   this License; and\n\n2. You must cause any modified files to carry prominent notices stating that\n   You changed the files; and\n\n3. You must retain, in the Source form of any Derivative Works that You\n   distribute, all copyright, patent, trademark, and attribution notices from\n   the Source form of the Work, excluding those notices that do not pertain to\n   any part of the Derivative Works; and\n\n4. If the Work includes a \"NOTICE\" text file as part of its distribution, then\n   any Derivative Works that You distribute must include a readable copy of the\n   attribution notices contained within such NOTICE file, excluding those\n   notices that do not pertain to any part of the Derivative Works, in at least\n   one of the following places: within a NOTICE text file distributed as part\n   of the Derivative Works; within the Source form or documentation, if\n   provided along with the Derivative Works; or, within a display generated by\n   the Derivative Works, if and wherever such third-party notices normally\n   appear. The contents of the NOTICE file are for informational purposes only\n   and do not modify the License. You may add Your own attribution notices\n   within Derivative Works that You distribute, alongside or as an addendum to\n   the NOTICE text from the Work, provided that such additional attribution\n   notices cannot be construed as modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.","ref":"license.html#4-redistribution"},{"type":"extras","title":"5. Submission of Contributions. - License (Apache 2.0)","doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.","ref":"license.html#5-submission-of-contributions"},{"type":"extras","title":"6. Trademarks. - License (Apache 2.0)","doc":"This License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.","ref":"license.html#6-trademarks"},{"type":"extras","title":"7. Disclaimer of Warranty. - License (Apache 2.0)","doc":"Unless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE, NON-\nINFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.","ref":"license.html#7-disclaimer-of-warranty"},{"type":"extras","title":"8. Limitation of Liability. - License (Apache 2.0)","doc":"In no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability"},{"type":"extras","title":"9. Accepting Warranty or Additional Liability. - License (Apache 2.0)","doc":"While redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS\n\nCopyright 2023, Jake Morrison  .\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\nhttp://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html#9-accepting-warranty-or-additional-liability"},{"type":"extras","title":"Contributing","doc":"# Contributing\n\nBuild:\n\n```console\nrebar3 compile\n```\n\nTest:\n\n```console\nrebar3 ct\n```\n\nFormat code:\n\n```console\nrebar3 steamroll\n```\n\nGenerate docs:\n\n```console\nrebar3 ex_doc\n```\n\nPublish:\n\n```console\nrebar3 hex user auth\nrebar3 hex build\nrebar3 hex publish\n```\n\nThis project uses the Contributor Covenant version 2.1. Check [CODE_OF_CONDUCT.md](/CODE_OF_CONDUCT.md) for more information.","ref":"contributing.html"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, caste, color, religion, or sexual\nidentity and orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official e-mail address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement at\nengineering@therealreal.com. All complaints will be reviewed and investigated\npromptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series of\nactions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or permanent\nban.","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior, harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within the\ncommunity.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].\n\nCommunity Impact Guidelines were inspired by\n[Mozilla's code of conduct enforcement ladder][Mozilla CoC].\n\nFor answers to common questions about this code of conduct, see the FAQ at\n[https://www.contributor-covenant.org/faq][FAQ]. Translations are available at\n[https://www.contributor-covenant.org/translations][translations].\n\n[homepage]: https://www.contributor-covenant.org\n[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html\n[Mozilla CoC]: https://github.com/mozilla/diversity\n[FAQ]: https://www.contributor-covenant.org/faq\n[translations]: https://www.contributor-covenant.org/translations","ref":"code_of_conduct.html#attribution"}],"proglang":"erlang","producer":{"name":"ex_doc","version":"0.35.1"},"content_type":"text/markdown"}